#
# spec file for package julia
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# We must not strip binaries in julia, since it can lead to many problems.
# For example, see:
#
# https://github.com/JuliaLang/julia/issues/17941
%undefine _build_create_debug
%define __arch_install_post export NO_BRP_STRIP_DEBUG=true

%define julia_ver            1.0.3
%define libjulia_sover_major 1
%define libjulia_sover_minor 0
%define libuv_ver    ed3700c849289ed01fe04273a7bf865340b2bd7e
%define libwhich_ver 81e9723c0273d78493dc8c8ed570f68d9ce7e89e
%define pkg_ver      93b6d6de857dc88e665d2c64397852ab9701ba24
%define utf8proc_ver 97ef668b312b96382714dbb8eaac4affce0816e6
%define llvm_ver     6.0.0
%define compat_mode  0
%define src_name     julia-tarball
%define libgit2_ver  %(rpm -qa | grep -E "^libgit2-[0-9]" | head -n1 | cut -d'-' -f2)
Version:        1.0.3
Release:        bp156.3.54
URL:            http://julialang.org/
Source0:        https://github.com/JuliaLang/julia/releases/download/v%{julia_ver}/julia-%{julia_ver}.tar.gz
# external sources
Source10:       https://api.github.com/repos/JuliaLang/libuv/tarball/%{libuv_ver}#/libuv-%{libuv_ver}.tar.gz
Source11:       https://api.github.com/repos/vtjnash/libwhich/tarball/%{libwhich_ver}#/libwhich-%{libwhich_ver}.tar.gz
Source12:       https://api.github.com/repos/JuliaLang/utf8proc/tarball/%{utf8proc_ver}#/utf8proc-%{utf8proc_ver}.tar.gz
Source13:       http://llvm.org/releases/%{llvm_ver}/llvm-%{llvm_ver}.src.tar.xz
Source14:       https://api.github.com/repos/JuliaLang/Pkg.jl/tarball/%{pkg_ver}#/Pkg-%{pkg_ver}.tar.gz
Source99:       juliabuildopts
# PATCH-FIX-OPENSUSE julia-env-script-interpreter.patch ronisbr@gmail.com -- Change script interpreted to avoid errors in rpmlint.
Patch0:         julia-env-script-interpreter.patch
BuildRequires:  arpack-ng-devel >= 3.3.0
BuildRequires:  blas-devel
BuildRequires:  cmake
BuildRequires:  dSFMT-devel >= 2.2.3
BuildRequires:  double-conversion-devel
BuildRequires:  fdupes
BuildRequires:  fftw3-threads-devel >= 3.3.4
BuildRequires:  gcc-c++
BuildRequires:  gcc-fortran
BuildRequires:  gmp-devel >= 6.1.2
BuildRequires:  hicolor-icon-theme
BuildRequires:  lapack-devel >= 3.5.0
BuildRequires:  libgit2-devel
BuildRequires:  libopenblas_openmp-devel >= 0.2.19
BuildRequires:  libunwind-devel > 1.1
BuildRequires:  m4
BuildRequires:  mpfr-devel >= 4.0.1
BuildRequires:  ncurses-devel
BuildRequires:  openlibm-devel
BuildRequires:  openspecfun-devel
BuildRequires:  openssl
BuildRequires:  patchelf >= 0.9
BuildRequires:  pcre2-devel >= 10.30
BuildRequires:  perl
BuildRequires:  python >= 2.5
BuildRequires:  readline-devel
BuildRequires:  suitesparse-devel >= 4.4.5
BuildRequires:  update-desktop-files
BuildRequires:  zlib-devel
Requires:       libamd2
Requires:       libarpack2
Requires:       libcamd2
Requires:       libccolamd2
Requires:       libcholmod3
Requires:       libcolamd2
Requires:       libdSFMT2_2 >= 2.2.3
Requires:       libfftw3_threads3
Requires:       libgit2-%{libgit2_ver}
Requires:       libgmp10
Requires:       libmpfr6
Requires:       libopenblas_openmp0 >= 0.2.19
Requires:       libpcre2-8-0
Requires:       libspqr2
Requires:       libsuitesparseconfig5
Requires:       libumfpack5
Requires:       ncurses
Requires:       readline
Recommends:     arpack-ng-devel
Recommends:     git
Recommends:     gmp-devel
Recommends:     mpfr-devel
Recommends:     openlibm-devel
Recommends:     openspecfun-devel
Recommends:     pcre2-devel
Recommends:     suitesparse-devel
%if 0%{?compat_mode} == 0
Name:           julia
%else
Name:           julia-compat
%endif
%if 0%{?compat_mode} == 0
Summary:        High-level, high-performance dynamic programming language
License:        MIT AND GPL-2.0-or-later AND BSD-3-Clause AND Zlib
Group:          Development/Languages/Other
%else
Summary:        High-level, high-performance dynamic programming language (without CPU optim.)
License:        MIT AND GPL-2.0-or-later AND BSD-3-Clause AND Zlib
Group:          Development/Languages/Other
%endif
%if 0%{?compat_mode}
Conflicts:      julia
Provides:       julia = %{version}
%endif
# Since the 32-bit julia package is already being built using MARCH=pentium4,
# which is the most generic flag supported, then the julia-compat mode only
# makes sense for 64-bit architectures.
%if 0%{?compat_mode}
ExclusiveArch:  x86_64
%else
ExclusiveArch:  %{ix86} x86_64 %{arm} aarch64 ppc64le
%endif

%description
Julia is a high-level, high-performance dynamic programming language for
technical computing, with syntax that is familiar to users of other technical
computing environments. It provides a sophisticated compiler, distributed
parallel execution, numerical accuracy, and an extensive mathematical function
library. The library, largely written in Julia itself, also integrates mature,
best-of-breed C and Fortran libraries for linear algebra, random number
generation, signal processing, and string processing.

%package        devel
Summary:        Julia development, debugging and testing files
Group:          Development/Languages/Other
Requires:       %{name} = %{version}
%if 0%{?compat_mode}
Conflicts:      julia-devel
%endif

%description    devel
Contains library symbolic links and header files for developing applications
linking to the Julia library, in particular embedding it, as well as tests and a
debugging version of Julia. This package is normally not needed when programming
in the Julia language, but rather for embedding Julia into external programs or
debugging Julia itself.

%package        debug
Summary:        Julia debugging
Group:          Development/Languages/Other
Requires:       %{name} = %{version}
%if 0%{?compat_mode}
Conflicts:      julia-debug
%endif

%description    debug
Contains a debugging version of Julia system image and Julia library.

%if 0%{?compat_mode} == 0
%package        doc
Summary:        Julia documentation and code examples
Group:          Documentation/Other
BuildArch:      noarch

%description    doc
Contains the Julia manual, the reference documentation of the standard library.

%endif

%{expand:%global juliabuildopts %(cat %{SOURCE99})}

%prep
%setup -q -n julia-%{version}
%patch0 -p1

# remove .gitignore
find . -name ".git*" -exec rm {} \;

pushd deps/
mkdir -p srccache/
pushd srccache/
cp %{SOURCE10} ./
cp %{SOURCE11} ./
cp %{SOURCE12} ./
cp %{SOURCE13} ./
cp %{SOURCE14} ./
popd
popd

%build

%if 0%{?compat_mode} == 0
    %ifarch x86_64
        %define julia_march core2
    %endif

    %ifarch %{ix86}
        %define julia_march pentium4
    %endif

    %ifarch aarch64
        %define julia_march armv8-a
    %endif

    %ifarch armv7l armv7hl
       %define julia_march armv7-a
    %endif

    %ifarch armv6l armv6hl
        %define julia_march armv6
    %endif

    %ifarch ppc64le
        %define julia_march ppc64le
    %endif
%else
    # compat_mode is only defined for 64-bit architecture.

    %define julia_march x86-64
%endif

%ifarch armv6l armv6hl
export LDFLAGS="$LDFLAGS -latomic"
%endif

%define julia_builddir %{_builddir}/%{name}/
make %{?_smp_mflags} MARCH=%{julia_march} \
                     prefix=%{_prefix} \
                     bindir=%{_bindir} \
                     libdir=%{_libdir} \
                     libexecdir=%{_libexecdir} \
                     datarootdir=%{_datarootdir} \
                     includedir=%{_includedir} \
                     sysconfdir=%{_sysconfdir} \
                     %{juliabuildopts} \
                     release debug

%check
# The tests will only pass if openblas is being used.
# make %{?_smp_mflags} test

%install
make install DESTDIR=%{buildroot} \
             MARCH=%{julia_march} \
             prefix=%{_prefix} \
             bindir=%{_bindir} \
             libdir=%{_libdir} \
             libexecdir=%{_libexecdir} \
             datarootdir=%{_datarootdir} \
             includedir=%{_includedir} \
             sysconfdir=%{_sysconfdir} \
             %{juliabuildopts}

# GZip man page.
gzip %{buildroot}/%{_mandir}/man1/julia.1

# Copy the man page for every executable.
cd %{buildroot}/%{_mandir}/man1/
ln -sf julia.1.gz julia-debug.1.gz

rm -f %{buildroot}%{_libdir}/julia/libuv.a
rm -f %{buildroot}%{_datadir}/julia/base/build.h
rm -f %{buildroot}%{_datadir}/julia/base/Makefile

# Fix documentation directories.
mkdir -p %{buildroot}%{_docdir}/julia
mv -f %{buildroot}%{_datadir}/doc/julia/* %{buildroot}%{_docdir}/julia/
rm -r %{buildroot}%{_datadir}/doc/julia

# Remove execution permission on documentation files.
chmod -x+X -R %{buildroot}%{_docdir}/julia/*

%if 0%{?compat_mode}
rm -rf %{buildroot}%{_docdir}/julia/

# The 'application' object must be only provided by one package
# Alternatively, we could rename the .appdata and .desktop file to have
# both applications show up in a valid way, but that would require the
# -compat appdata to be modified to make the difference clear
rm %{buildroot}%{_datadir}/appdata/julia.appdata.xml
%endif

# Remove duplicated files.
%fdupes %{buildroot}%{_datadir}/

%suse_update_desktop_file -r julia Science Math

%post         -p /sbin/ldconfig
%postun       -p /sbin/ldconfig
%post   devel -p /sbin/ldconfig
%postun devel -p /sbin/ldconfig
%post   debug -p /sbin/ldconfig
%postun debug -p /sbin/ldconfig

%files
%doc CONTRIBUTING.md NEWS.md README.md
%license LICENSE.md
%{_bindir}/julia
%dir %{_datadir}/julia
%{_datadir}/julia/base
%{_datadir}/julia/base.cache
%{_datadir}/julia/stdlib
%if !%{?compat_mode}
%dir %{_datadir}/appdata/
%{_datadir}/appdata/julia.appdata.xml
%endif
%{_datadir}/applications/julia.desktop
%{_datadir}/icons/hicolor/scalable/apps/julia.svg
%{_libdir}/julia/
%{_libdir}/libjulia.so.%{libjulia_sover_major}.%{libjulia_sover_minor}
%{_mandir}/man1/julia.1%{?ext_man}
%dir %{_sysconfdir}/julia/
%config(noreplace) %{_sysconfdir}/julia/startup.jl
# Exclude debugging files.
%exclude %{_libdir}/julia/libccalltest.so.debug
%exclude %{_libdir}/julia/sys-debug.so
# Exclude documentation.
%exclude %{_docdir}/julia/html

%files devel
%{_datadir}/julia/test/
%{_datadir}/julia/build_sysimg.jl
%{_datadir}/julia/julia-config.jl
%{_includedir}/julia/
%{_libdir}/libjulia.so.%{libjulia_sover_major}
%{_libdir}/libjulia.so

%files debug
%{_bindir}/julia-debug
%{_libdir}/libjulia-debug.so.%{libjulia_sover_major}.%{libjulia_sover_minor}
%{_libdir}/libjulia-debug.so.%{libjulia_sover_major}
%{_libdir}/libjulia-debug.so
%{_libdir}/julia/libccalltest.so.debug
%{_libdir}/julia/sys-debug.so
%{_mandir}/man1/julia-debug.1%{?ext_man}

%if 0%{?compat_mode} == 0
%files doc
%{_docdir}/julia
%exclude %{_docdir}/julia/CONTRIBUTING.md
%exclude %{_docdir}/julia/LICENSE.md
%exclude %{_docdir}/julia/NEWS.md
%exclude %{_docdir}/julia/README.md
%endif

%changelog
* Mon Mar  9 2020 Ronan Chagas <ronisbr@gmail.com>
- Remove constraints of CPU flag since it was blocking the builds.
* Sun Dec 16 2018 ronisbr@gmail.com
- Version bump to 1.0.3.
  * Bugfix release, no changelog available.
* Mon Nov  5 2018 Ronan Chagas <ronisbr@gmail.com>
- Version bump to 1.0.1.
  * Bugfix release, no changelog available.
* Mon Sep 24 2018 Ronan Chagas <ronisbr@gmail.com>
- Version bump to 1.0.0.
  * v1.0.0 is basically v0.7.0 without deprecation warnings.
* Wed Aug  8 2018 ronisbr@gmail.com
- Version bump to 0.7.0, see NEWS.md for details.
- Add new required bundled dependency by the new v0.7.0.
  * libwhich: 81e9723c0273d78493dc8c8ed570f68d9ce7e89e
- Bump bundled dependencies as required by the new v0.7.0.
  * libuv: ed3700c849289ed01fe04273a7bf865340b2bd7e
  * llvm: 6.0.0
- Update patch `julia-env-script-interpreter.patch`.
- Remove unnecessary bundled dependency:
  * Rmath: julia-0.1
- Remove empty package `julia-examples`.
* Sun Jul 22 2018 ronisbr@gmail.com
- Version bump to 0.6.4.
  * Bugfix release, no changelog available.
* Fri Jun  1 2018 ronisbr@gmail.com
- Version bump to 0.6.3.
  * Bugfix release, no changelog available.
- Bump utf8proc version as required by the new v0.6.3.
- Change LICENSE.md from %%doc to %%license.
* Thu Apr 19 2018 guillaume.gardet@opensuse.org
- Pass right MARCH value for ppc64le
- Build only for supported architectures
- Fix armv6 build by passing atomic lib to linker
* Tue Mar 27 2018 guillaume.gardet@opensuse.org
- Pass right march option for %%arm and aarch64
* Wed Dec 20 2017 ronisbr@gmail.com
- Remove patch `julia-0.6.1-dont-rebuild-docs-on-install.patch`,
  since the issue was already fixed by upstream.
- Version bump to 0.6.2.
  * Bugfix release, no changelog available.
- Update license information according to file `LICENSE.md`.
* Wed Nov  1 2017 ronisbr@gmail.com
- Run spec-cleaner.
- Version bump to 0.6.1.
  * Bugfix release, no changelog available.
- Add patches:
  * `julia-0.6.1-dont-rebuild-docs-on-install.patch`
    This patch avoids documentation rebuilding in `make
    install` command. For more information, see:
    https://github.com/JuliaLang/julia/issues/24432
  * `julia-env-script-interpreter.patch`
    This patch removes a RPMLINT error.
* Sat Aug 19 2017 ronisbr@gmail.com
- Add script to get the right libgit2 version. Hence, it will not
  be necessary anymore to update the .spec every time libgit2 is
  updated.
* Fri Aug 18 2017 ronisbr@gmail.com
- Update runtime dependency: `libgit2-25` -> `libgit2-26`.
* Mon Jul  3 2017 ronisbr@gmail.com
- Version bump to 0.6.0, see NEWS.md for details.
- Remove unneeded patch `julia-disable-llvm-timestamps.patch`.
* Fri Mar 24 2017 ronisbr@gmail.com
- Update runtime dependency: `libgit2-24` -> `libgit2-25`.
  * Fixes boo#1030824.
* Wed Mar  8 2017 ronisbr@gmail.com
- Version bump to 0.5.1.
  * Bugfix release, no changelog available.
- Update patch `julia-disable-llvm-timestamps.patch`.
* Mon Oct 31 2016 ronisbr@gmail.com
- Add `libdSFMT2_2` as runtime dependency, since rpm is not
  automatically adding it.
* Tue Sep 20 2016 ronisbr@gmail.com
- Version bump to 0.5.0, see NEWS.md for details.
* Tue Sep 13 2016 ronisbr@gmail.com
- Version bump to 0.5.0~rc4.
  * The changelog will be available when the version 0.5.0 is
    released.
- Julia is now built using `libopenblas_openmp0` as the lapack and
  blas libraries due to upstream advice. For more information, see:
    https://github.com/JuliaLang/julia/issues/18394
- Remove white spaces in .changes files.
* Tue Aug 30 2016 ronisbr@gmail.com
- Fix `julia-debug` dependency.
- Move `libccalltest.so.debug` to `julia-debug` package
* Thu Aug 25 2016 ronisbr@gmail.com
- Version bump to 0.5.0~rc3;
  * The changelog will be available when the version 0.5.0 is
    released.
- Remove unnecessary build options `USE_SYSTEM_MBEDTLS=1` and
  `USE_SYSTEM_LIBSSH2=1`, because we are using the system libgit2
  to build julia. For more information, see:
    https://github.com/JuliaLang/julia/issues/17884
* Mon Aug 22 2016 ronisbr@gmail.com
- Add `libgit2` as a runtime dependency.
* Fri Aug 12 2016 ronisbr@gmail.com
- Version bump to 0.5.0~rc2.
  * The changelog will be available when the version 0.5.0 is
    released.
* Thu Aug 11 2016 ronisbr@gmail.com
- Version bump to 0.5.0~rc1.
  * The changelog will be available when the version 0.5.0 is
    released.
- Add package `julia-debug`, which contains a debugging version of
  Julia system image and Julia library.
* Thu Aug  4 2016 ronisbr@gmail.com
- User oertel (ro@suse.com) fix the `_constraints` file because the
  sse flags only exists in x86 architectures. See Request 416497.
* Wed Jun 22 2016 ronisbr@gmail.com
- Version bump to 0.4.6.
  * Bugfix release, no changelog available.
- Re-enable i586 architecture.
  * After the full rebuild caused by gcc6, julia started to
    correctly build against i586 again. The root cause of the
    problem was not identified yet.
* Fri Apr 29 2016 ronisbr@gmail.com
- Due to a bug, it is not possible now to build julia against i586
  with glibc 2.23. The root of the problem has not been determined
  yet. Two bugs were filled in upstream:
    _ https://github.com/JuliaLang/julia/issues/16087
    _ https://llvm.org/bugs/show_bug.cgi?id=27548
  Thus, the support for julia in i586 architectures is being
  dropped until this bug is fixed.
* Mon Mar 21 2016 ronisbr@gmail.com
- Version bump to 0.4.5.
  * Bugfix release, no changelog available.
  * Note: Version 0.4.4 has a known bug with Pkg.publish
    (gh#JuliaLang/julia#15381). Thus, it was skipped.
* Fri Jan 29 2016 dimstar@opensuse.org
- Do not install julia.appdata.xml when building julia-compat:
  The application 'julia' must exist only once in the repository.
* Thu Jan 21 2016 ronisbr@gmail.com
- Add in _constraints the information to build julia package in a
  machine that supports the following extensions: mmx, sse, sse2,
  sse3, and ssse3. This is necessary because the main package is
  built for core2 architecture to improve the performance. The
  package julia-compat, on the other hand, is built for x86_64 and
  can be used if the user does not support core2 extensions.
* Tue Jan 19 2016 ronisbr@gmail.com
- Version bump to 0.4.3.
  * Bugfix release, no changelog available.
- libuv updated to commit efb40768b7c7bd9f173a7868f74b92b1c5a61a0e
- Run spec-cleaner.
* Tue Dec  8 2015 ronisbr@gmail.com
- Version bump to 0.4.2.
  * Bugfix release, no changelog available.
- libuv updated to commit 9ab431a88fe255dd21e19a11f7fa2dd95774abf4.
- Run spec-cleaner.
* Mon Nov 16 2015 ronisbr@gmail.com
- Version bump to 0.4.1.
  * Bugfix release, no changelog available.
* Mon Oct 12 2015 lorddarthfener@gmail.com
- Add missing runtime dependency on libpcre2-8-0
* Fri Oct  9 2015 ronisbr@gmail.com
- Version bump to 0.4.0, see NEWS.md for details.
* Wed Oct  7 2015 ronisbr@gmail.com
- Remove unneeded build dependencies.
- Version bump to 0.4.0~rc4.
  * Bugfix and backports towards 0.4 release. No changelog
    available.
* Sat Oct  3 2015 dmitry_r@opensuse.org
- Add julia-compat package without CPU optimizations
* Thu Oct  1 2015 ronisbr@gmail.com
- Version bump to 0.4.0~rc3.
  * Bugfix and backports towards 0.4 release. No changelog
    available.
* Tue Sep 22 2015 ronisbr@gmail.com
- Version bump to 0.4.0~rc2.
  * Bugfix and backports towards 0.4 release. No changelog
    available.
* Fri Sep 18 2015 ronisbr@gmail.com
- LLVM 3.3 will be bundle for 0.4 branch.
  * LLVM 3.3 will be bundle until upstream change the supported
    version. As it can be seen in upstream issues #9336 and
    [#13209], there are still many problems related with LLVM 3.5,
    regarding both the build process and the JIT compiler used
    by Julia. Thus, it is better for now stick with LLVM 3.3.
    For more information, see:
    https://github.com/JuliaLang/julia/issues/13208
    https://github.com/JuliaLang/julia/issues/9336
* Fri Sep 18 2015 ronisbr@gmail.com
- Version bump to 0.4 branch (0.4.0~rc1).
  * This version needs utf8proc > 1.3. Since it is not available
    in openSUSE yet, it was decided to bundle the selected
    upstream version.
  * This version seems to build correctly with both LLVM 3.5 and
    3.7, which are the versions available in 13.2 and
    Tumbleweed. Thus, it was decided to build julia against
    system LLVM.
  * The build process now requires libgit2 and pcre2.
  * The changes in .spec were obtained from Fedora's
    julia-nightlies.spec.
- Changelog of verion 0.4.0~rc1.
  * The complete list of changes related to this release
    candidate can be seen in:
    https://github.com/JuliaLang/julia/issues?q=milestone%%3A0.4.0+is%%3Aclosed
  * Note: a changelog with the notable changes between 0.3 and
    0.4 versions are expected in the Julia 0.4 release
    announcement.
* Thu Aug 20 2015 ronisbr@gmail.com
- Revert: "Build julia using llvm-3_3 package" (Revision 15)
  * The llvm-3_3 package is conflicting with other packages that
    depends on llvm and it turns out that it will need a huge
    amount of work to modify every package spec that depends on
    llvm to circumvent this problem. Thus, by now, the safest
    approach is just bundle the supported llvm version in julia
    package.
* Wed Jul 29 2015 ronisbr@gmail.com
- Update to version 0.3.11
  * Bugfix release, no changelog available
* Sun Jul 26 2015 ronisbr@gmail.com
- Drop obsolete julia-disable-llvm-timestamps.patch
- Fix compiler names (clang++ -> clang++-3.3 in llvm-3_3-clang)
* Sun Jul 26 2015 ronisbr@gmail.com
- Build julia using llvm-3_3 package.
* Wed Jul 15 2015 ronisbr@gmail.com
- Use build-in LLVM 3.3
- Disable LLVM timestamps
  * julia-disable-llvm-timestamps.patch
- Drop obsolete julia_Fix-building-with-MCJIT-LLVM.patch
- Set required memory to 4 Gb
* Mon Jul  6 2015 ronisbr@gmail.com
- Update to version 0.3.10
  * Bugfix release, no changelog available
* Tue Jun  2 2015 ronisbr@gmail.com
- Update to version 0.3.9
  * Bugfix release, no changelog available
* Sat May  2 2015 ronisbr@gmail.com
- Update to version 0.3.8
  * Bugfix release, no changelog available
* Wed Mar 25 2015 ronisbr@gmail.com
- Update to version 0.3.7
  * Bugfix release, no changelog available
* Fri Feb 20 2015 ronisbr@gmail.com
- Update to version 0.3.6
  * Bugfix release, no changelog available
* Sat Jan 10 2015 ronisbr@gmail.com
- Update to version 0.3.5
  * Bugfix release, no changelog available
* Mon Dec 29 2014 ronisbr@gmail.com
- Update to version 0.3.4
  * Bugfix release, no changelog available
- Set USE_SYSTEM_LIBM=0
  * If USE_SYSTEM_LIBM is set to 1, then julia will not use
    openlibm.
- Set MARCH=pentium4 (32 bits) / MARCH=core2 (64 bits)
- Add libarpack2 to the dependency list
- Remove upstreamed julia-upstream-9221.patch
* Sat Dec 20 2014 ronisbr@gmail.com
- Add julia-upstream-9221.patch to temporarily fix the upstream issue:
  https://github.com/JuliaLang/julia/issues/8690
* Sat Dec 20 2014 ronisbr@gmail.com
- Fix bug related with build architecture (JULIA_CPU_TARGET) that
  was added by revision 15 of science repo.
* Fri Dec 19 2014 matwey.kornilov@gmail.com
- Deduce JULIA_TARGET_ARCH from RPM build flags, specifying just
  JULIA_CPU_TARGET=core2 is not portable
* Wed Nov 26 2014 dmitry_r@opensuse.org
- Update to version 0.3.3
  * Bugfix release, no changelog available
* Tue Oct 21 2014 dmitry_r@opensuse.org
- Update to version 0.3.2
  * Bugfix release, no changelog available
* Fri Oct 17 2014 dmitry_r@opensuse.org
- Update to version 0.3.1
  * Bugfix release, no changelog available
* Thu Aug 21 2014 dmitry_r@opensuse.org
- Update to version 0.3.0
  * See included NEWS.md for details
- Add _service in disabled mode for Rmath and libuv sources
* Fri Aug 15 2014 dmitry_r@opensuse.org
- Update to version 0.3.0-rc4
* Sun Aug 10 2014 dmitry_r@opensuse.org
- Update to version 0.3.0-rc3
* Wed Aug  6 2014 dmitry_r@opensuse.org
- Update to version 0.3.0-rc2
- spec file cleanup
- Use system openlibm, openspecfun, utf8proc
- Use FFTW3 with multithreading support
- Move build parameters to juliabuildopts file
- Move code examples to separate package
* Wed Jul 16 2014 ronisbr@gmail.com
- Julia 0.3.0-rc1 (0.2.0+git4218.gc5acc8d)
